@@ -1,9 +1,18 @@
 from scipy.stats import lomax, rv_continuous
 
+from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
+    LambdaFloatDMixin
+from probability.distributions.mixins.calculable_mixins import CalculableMixin
 from probability.distributions.mixins.rv_continuous_1d_mixin import RVContinuous1dMixin
 
 
-class Lomax(RVContinuous1dMixin):
+class Lomax(
+    RVContinuous1dMixin,
+    AlphaFloatDMixin,
+    LambdaFloatDMixin,
+    CalculableMixin,
+    object
+):
     """
     The Lomax distribution, conditionally also called the Pareto Type II
     distribution, is a heavy-tail probability distribution used in business,
@@ -26,24 +35,6 @@ class Lomax(RVContinuous1dMixin):
             c=self._alpha, scale=self._lambda
         )
 
-    @property
-    def lambda_(self) -> float:
-        return self._lambda
-
-    @lambda_.setter
-    def lambda_(self, value: float):
-        self._lambda = value
-        self._reset_distribution()
-
-    @property
-    def alpha(self) -> float:
-        return self._alpha
-
-    @alpha.setter
-    def alpha(self, value: float):
-        self._alpha = value
-        self._reset_distribution()
-
     def __str__(self):
 
         return f'Lomax(λ={self._lambda}, α={self._alpha})'
