@@ -1,9 +1,16 @@
 from scipy.stats import geom, rv_discrete
 
+from probability.distributions.mixins.attributes import PFloatDMixin
+from probability.distributions.mixins.calculable_mixins import CalculableMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import RVDiscrete1dMixin
 
 
-class Geometric(RVDiscrete1dMixin):
+class Geometric(
+    RVDiscrete1dMixin,
+    PFloatDMixin,
+    CalculableMixin,
+    object
+):
     """
     The (shifted) geometric distribution gives the probability that the first
     occurrence of success requires k independent trials, each with success
@@ -24,15 +31,6 @@ class Geometric(RVDiscrete1dMixin):
 
         self._distribution: rv_discrete = geom(self._p)
 
-    @property
-    def p(self) -> float:
-        return self._p
-
-    @p.setter
-    def p(self, value: float):
-        self._p = value
-        self._reset_distribution()
-
     def __str__(self):
 
         return f'Geometric(p={self._p})'
