@@ -1,9 +1,17 @@
 from scipy.stats import poisson, rv_discrete
 
-from probability.distributions.mixins.rv_discrete_1d_mixin import RVDiscrete1dMixin
+from probability.distributions.mixins.attributes import LambdaFloatDMixin
+from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.rv_discrete_1d_mixin import \
+    RVDiscrete1dMixin
 
 
-class Poisson(RVDiscrete1dMixin):
+class Poisson(
+    RVDiscrete1dMixin,
+    LambdaFloatDMixin,
+    CalculableMixin,
+    object
+):
     """
     The Poisson distribution is a discrete probability distribution that
     expresses the probability of a given number of events occurring in a fixed
@@ -14,28 +22,19 @@ class Poisson(RVDiscrete1dMixin):
 
     https://en.wikipedia.org/wiki/Poisson_distribution
     """
-    def __init__(self, lambda_: int):
+    def __init__(self, lambda_: float):
         """
         Create a new poisson distribution.
 
         :param lambda_: Average rate at which events occur.
         """
-        self._lambda: int = lambda_
+        self._lambda: float = lambda_
         self._reset_distribution()
 
     def _reset_distribution(self):
 
         self._distribution: rv_discrete = poisson(self._lambda)
 
-    @property
-    def lambda_(self) -> int:
-        return self._lambda
-
-    @lambda_.setter
-    def lambda_(self, value: int):
-        self._lambda = value
-        self._reset_distribution()
-
     def __str__(self):
 
         return f'Poisson(λ={self._lambda})'
