@@ -7,15 +7,14 @@ from probability.distributions.mixins.plottable_mixin import \
 from probability.distributions.mixins.rv_mixins import RVS1dMixin, \
     EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin, Var1dMixin, \
     Interval1dMixin, PMF1dMixin, CDFDiscrete1dMixin, SFDiscrete1dMixin, \
-    PPFDiscrete1dMixin, ISFDiscrete1dMixin
+    PPFDiscrete1dMixin, ISFDiscrete1dMixin, StatMixin
 
 
 class RVDiscrete1dMixin(
     RVS1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin,
     Var1dMixin, Interval1dMixin, PMF1dMixin, CDFDiscrete1dMixin,
     SFDiscrete1dMixin, PPFDiscrete1dMixin, ISFDiscrete1dMixin,
-    DiscretePlottableMixin,
-    object
+    DiscretePlottableMixin, StatMixin, object
 ):
 
     _distribution: rv_discrete
