@@ -1,12 +1,17 @@
 from numpy import ndarray
+from pandas import DataFrame, Series, MultiIndex
 from scipy.stats import rv_continuous, rv_discrete
 from scipy.stats._distn_infrastructure import rv_generic
-from typing import Tuple, Optional, Union, Iterable
+from typing import Tuple, Optional, Union, Iterable, List
 
-from probability.distributions.functions.continuous_function_1d import ContinuousFunction1d
-from probability.distributions.functions.continuous_function_nd import ContinuousFunctionNd
-from probability.distributions.functions.discrete_function_1d import DiscreteFunction1d
-from probability.distributions.functions.discrete_function_nd import DiscreteFunctionNd
+from probability.distributions.functions.continuous_function_1d import \
+    ContinuousFunction1d
+from probability.distributions.functions.continuous_function_nd import \
+    ContinuousFunctionNd
+from probability.distributions.functions.discrete_function_1d import \
+    DiscreteFunction1d
+from probability.distributions.functions.discrete_function_nd import \
+    DiscreteFunctionNd
 
 NUM_SAMPLES_COMPARISON = 100000
 
@@ -16,12 +21,16 @@ class RVS1dMixin(object):
     _distribution: rv_generic
 
     def rvs(self, num_samples: int,
-            random_state: Optional[int] = None) -> ndarray:
+            random_state: Optional[int] = None) -> Series:
         """
         Sample `num_samples` random values from the distribution.
         """
-        return self._distribution.rvs(size=num_samples,
-                                      random_state=random_state)
+        samples = Series(self._distribution.rvs(
+            size=num_samples, random_state=random_state
+        ))
+        samples.index.name = 'sample_index'
+        samples.name = str(self)
+        return samples
 
     def prob_greater_than(self, other: 'RVS1dMixin',
                           num_samples: int = NUM_SAMPLES_COMPARISON) -> float:
@@ -51,14 +60,25 @@ class RVS1dMixin(object):
 class RVSNdMixin(object):
 
     _distribution: rv_generic
+    _names: List[str]
 
     def rvs(self, num_samples: int,
-            random_state: Optional[int] = None) -> ndarray:
+            random_state: Optional[int] = None,
+            full_name: bool = False) -> DataFrame:
         """
         Sample `num_samples` random values from the distribution.
         """
-        return self._distribution.rvs(size=num_samples,
-                                      random_state=random_state)
+        if full_name:
+            columns = [f'{str(self)}[{name}]' for name in self._names]
+        else:
+            columns = self._names
+        samples = DataFrame(
+            data=self._distribution.rvs(size=num_samples,
+                                        random_state=random_state),
+            columns=columns
+        )
+        samples.index.name = 'sample_index'
+        return samples
 
     def prob_greater_than(self, other: 'RVSNdMixin',
                           num_samples: int = NUM_SAMPLES_COMPARISON) -> ndarray:
