@@ -5,12 +5,19 @@ from numpy import array, ndarray
 from scipy.stats import multivariate_normal
 from scipy.stats._multivariate import multi_rv_generic
 
-from probability.custom_types import FloatOrFloatArray1d, FloatOrFloatArray2d
-from probability.distributions.mixins.rv_mixins import RVSNdMixin, EntropyMixin, PDFNdMixin, CDFContinuousNdMixin
+from probability.custom_types.external_custom_types import \
+    FloatOrFloatArray1d, FloatOrFloatArray2d
+from probability.distributions.mixins.calculable_mixins import CalculableMixin
+from probability.distributions.mixins.rv_mixins import \
+    RVSNdMixin, EntropyMixin, PDFNdMixin, CDFContinuousNdMixin
 
 
 class MVNormal(
-    RVSNdMixin, CDFContinuousNdMixin, PDFNdMixin, EntropyMixin,
+    RVSNdMixin,
+    CDFContinuousNdMixin,
+    PDFNdMixin,
+    EntropyMixin,
+    CalculableMixin,
     object
 ):
 
